extern crate css_modules;

use css_modules::*;

fn main() {
    let css = include_css_module!("main.css");

    let html = format!(
        r#"<!DOCTYPE html>
<style type="text/css">{}</style>
<p class="{}">Hello World</p>"#,
        css,
        css.id("message").unwrap()
    );

    println!("{}", html);
}
